#!/usr/bin/env node

/**
 * Tmplify prototype.
 */

'use strict'

process.chdir(`${__dirname}/..`)

const path = require('path'),
    fs = require('fs'),
    apeTasking = require('ape-tasking'),
    tmplconv = require('tmplconv')

const scff = require('../lib')

const demo = path.dirname(require.resolve('apeman-demo-task/package.json')),
    demoPkg = require('apeman-demo-task/package.json')

apeTasking.runTasks('tmplify', [
    (callback) => {
        tmplconv.tmplify(demo, 'asset/tmpl', {
            clean: true,
            mode: '444',
            pattern: [
                '**/*.*',
                '.*',
                '+(lib|test)/.*.bud',
                '+(lib|test)/.*.hbs'
            ],
            ignore: [
                '.DS_Store',
                '.svg',
                'ci/demo.js',
                'node_modules/**/*.*'
            ],
            data: {
                'github_repository': "apeman-demo-labo/apeman-demo-task",
                'package_name': 'apeman-demo-task',
                'package_description': 'Demo of task project.',
                'author_name': demoPkg.author.name,
                'author_email': demoPkg.author.email,
                'author_url': demoPkg.author.url
            },
            prefix: scff.prefix,
            suffix: scff.suffix
        }, callback)
    },
    (callback) => {
        tmplconv.tmplify(__dirname + '/..', 'asset/tmpl', {
            pattern: [
                '.gitignore'
            ],
            prefix: scff.prefix,
            suffix: scff.suffix
        }, callback)
    },
    (callback) => {
        let filename = require.resolve('../asset/tmpl/package.json.tmpl')
        let str = fs.readFileSync(filename).toString()
        let pkg = JSON.parse(str)
        fs.chmodSync(filename, '644')
        fs.writeFileSync(filename, JSON.stringify({
            name: pkg.name,
            version: '1.0.0',
            description: pkg.description,
            main: pkg.main,
            scripts: pkg.scripts,
            repository: pkg.repository.url.split(/\//g).slice(-1).join('/').replace(/\.git$/, ''),
            keywords: pkg.keywords,
            author: pkg.author,
            license: pkg.license,
            bugs: pkg.bugs,
            homepage: pkg.homepage,
            dependencies: pkg.dependencies,
            devDependencies: pkg.devDependencies,
            engines: pkg.engines
        }, null, 2))
        fs.chmodSync(filename, '444')
        callback(null)
    }
], true)
